---
name: Report issue
about: Create a bug report to help us improve `biocontext_kb`
title: ""
labels: bug
assignees: ""
---

This template should only be used for reporting bugs. For feature requests or help on how to best use `biocontext_kb`,
please use a different template.
Please provide a descriptive title describing which part of the software is broken and in what way.

## Expected Behavior

Describe in detail which part of the software you are using and what you think it should be doing.

## Current Behavior

In what way does the current behavior differ from what you expected?

## Possible Solution

Do you have a suggested solution?

## Steps to Reproduce

Please provide detailed reproduction steps. Code examples are very much appreciated.

## Environment

Describe your environment, software version, machine configuration and other variables.

## Further Description

Please add any other details you think may be relevant.
